@@ -29,7 +29,14 @@ class CommunityPermissions(LDPPermissions):
             if membership:
                 perms = perms.union({'view', 'add'})
 
+                # objects of community other than members can be deleted by any member
+                if not hasattr(obj, 'is_admin'):
+                    perms.union({'delete'})
+
+                # Admins can delete objects of communities
                 if getattr(membership, 'is_admin', False):
-                    perms = perms.union({'change', 'delete'})
+                    # But admins can't remove other admins from community
+                    if not getattr(obj, 'is_admin', False):
+                        perms = perms.union({'delete'})
 
         return list(perms)
